==> hpccm-20.4.0.tar.gz: hpccm-20.4.0/hpccm/building_blocks/__init__.py <==
# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import

__all__ = ['apt_get',
           'arm_allinea_studio',
           'boost',
           'catalyst',
           'cgns',
           'charm',
           'cmake',
           'conda',
           'fftw',
           'gdrcopy',
           'generic_autotools',
           'generic_build',
           'generic_cmake',
           'gnu',
           'hdf5',
           'hpcx',
           'intel_mpi',
           'intel_psxe',
           'intel_psxe_runtime',
           'julia',
           'knem',
           'kokkos',
           'libsim',
           'llvm',
           'magma',
           'mkl',
           'mlnx_ofed',
           'mpich',
           'multi_ofed',
           'mvapich2_gdr',
           'mvapich2',
           'netcdf',
           'nsight_systems',
           'ofed',
           'openblas',
           'openmpi',
           'packages',
           'pgi',
           'pip',
           'pmix',
           'pnetcdf',
           'python',
           'scif',
           'sensei',
           'slurm_pmi2',
           'ucx',
           'xpmem',
           'yum']

from hpccm.building_blocks.apt_get import apt_get
from hpccm.building_blocks.arm_allinea_studio import arm_allinea_studio
from hpccm.building_blocks.boost import boost
from hpccm.building_blocks.catalyst import catalyst
from hpccm.building_blocks.cgns import cgns
from hpccm.building_blocks.charm import charm
from hpccm.building_blocks.cmake import cmake
from hpccm.building_blocks.conda import conda
from hpccm.building_blocks.fftw import fftw
from hpccm.building_blocks.gdrcopy import gdrcopy
from hpccm.building_blocks.generic_autotools import generic_autotools
from hpccm.building_blocks.generic_build import generic_build
from hpccm.building_blocks.generic_cmake import generic_cmake
from hpccm.building_blocks.gnu import gnu
from hpccm.building_blocks.hdf5 import hdf5
from hpccm.building_blocks.hpcx import hpcx
from hpccm.building_blocks.intel_mpi import intel_mpi
from hpccm.building_blocks.intel_psxe import intel_psxe
from hpccm.building_blocks.intel_psxe_runtime import intel_psxe_runtime
from hpccm.building_blocks.julia import julia
from hpccm.building_blocks.knem import knem
from hpccm.building_blocks.kokkos import kokkos
from hpccm.building_blocks.libsim import libsim
from hpccm.building_blocks.llvm import llvm
from hpccm.building_blocks.magma import magma
from hpccm.building_blocks.mkl import mkl
from hpccm.building_blocks.mlnx_ofed import mlnx_ofed
from hpccm.building_blocks.mpich import mpich
from hpccm.building_blocks.multi_ofed import multi_ofed
from hpccm.building_blocks.mvapich2_gdr import mvapich2_gdr
from hpccm.building_blocks.mvapich2 import mvapich2
from hpccm.building_blocks.netcdf import netcdf
from hpccm.building_blocks.nsight_systems import nsight_systems
from hpccm.building_blocks.ofed import ofed
from hpccm.building_blocks.openblas import openblas
from hpccm.building_blocks.openmpi import openmpi
from hpccm.building_blocks.packages import packages
from hpccm.building_blocks.pgi import pgi
from hpccm.building_blocks.pip import pip
from hpccm.building_blocks.pmix import pmix
from hpccm.building_blocks.pnetcdf import pnetcdf
from hpccm.building_blocks.python import python
from hpccm.building_blocks.scif import scif
from hpccm.building_blocks.sensei import sensei
from hpccm.building_blocks.slurm_pmi2 import slurm_pmi2
from hpccm.building_blocks.ucx import ucx
from hpccm.building_blocks.xpmem import xpmem
from hpccm.building_blocks.yum import yum

==> hpccm-20.6.0.tar.gz: hpccm-20.6.0/hpccm/building_blocks/__init__.py <==
# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import

__all__ = ['amgx',
           'apt_get',
           'arm_allinea_studio',
           'boost',
           'catalyst',
           'cgns',
           'charm',
           'cmake',
           'conda',
           'fftw',
           'gdrcopy',
           'generic_autotools',
           'generic_build',
           'generic_cmake',
           'gnu',
           'hdf5',
           'hpcx',
           'intel_mpi',
           'intel_psxe',
           'intel_psxe_runtime',
           'julia',
           'knem',
           'kokkos',
           'libsim',
           'llvm',
           'magma',
           'mkl',
           'mlnx_ofed',
           'mpich',
           'multi_ofed',
           'mvapich2_gdr',
           'mvapich2',
           'netcdf',
           'nsight_systems',
           'nv_hpc_sdk',
           'nvshmem',
           'ofed',
           'openblas',
           'openmpi',
           'packages',
           'pgi',
           'pip',
           'pmix',
           'pnetcdf',
           'python',
           'scif',
           'sensei',
           'slurm_pmi2',
           'ucx',
           'xpmem',
           'yum']

from hpccm.building_blocks.amgx import amgx
from hpccm.building_blocks.apt_get import apt_get
from hpccm.building_blocks.arm_allinea_studio import arm_allinea_studio
from hpccm.building_blocks.boost import boost
from hpccm.building_blocks.catalyst import catalyst
from hpccm.building_blocks.cgns import cgns
from hpccm.building_blocks.charm import charm
from hpccm.building_blocks.cmake import cmake
from hpccm.building_blocks.conda import conda
from hpccm.building_blocks.fftw import fftw
from hpccm.building_blocks.gdrcopy import gdrcopy
from hpccm.building_blocks.generic_autotools import generic_autotools
from hpccm.building_blocks.generic_build import generic_build
from hpccm.building_blocks.generic_cmake import generic_cmake
from hpccm.building_blocks.gnu import gnu
from hpccm.building_blocks.hdf5 import hdf5
from hpccm.building_blocks.hpcx import hpcx
from hpccm.building_blocks.intel_mpi import intel_mpi
from hpccm.building_blocks.intel_psxe import intel_psxe
from hpccm.building_blocks.intel_psxe_runtime import intel_psxe_runtime
from hpccm.building_blocks.julia import julia
from hpccm.building_blocks.knem import knem
from hpccm.building_blocks.kokkos import kokkos
from hpccm.building_blocks.libsim import libsim
from hpccm.building_blocks.llvm import llvm
from hpccm.building_blocks.magma import magma
from hpccm.building_blocks.mkl import mkl
from hpccm.building_blocks.mlnx_ofed import mlnx_ofed
from hpccm.building_blocks.mpich import mpich
from hpccm.building_blocks.multi_ofed import multi_ofed
from hpccm.building_blocks.mvapich2_gdr import mvapich2_gdr
from hpccm.building_blocks.mvapich2 import mvapich2
from hpccm.building_blocks.netcdf import netcdf
from hpccm.building_blocks.nsight_systems import nsight_systems
from hpccm.building_blocks.nv_hpc_sdk import nv_hpc_sdk
from hpccm.building_blocks.nvshmem import nvshmem
from hpccm.building_blocks.ofed import ofed
from hpccm.building_blocks.openblas import openblas
from hpccm.building_blocks.openmpi import openmpi
from hpccm.building_blocks.packages import packages
from hpccm.building_blocks.pgi import pgi
from hpccm.building_blocks.pip import pip
from hpccm.building_blocks.pmix import pmix
from hpccm.building_blocks.pnetcdf import pnetcdf
from hpccm.building_blocks.python import python
from hpccm.building_blocks.scif import scif
from hpccm.building_blocks.sensei import sensei
from hpccm.building_blocks.slurm_pmi2 import slurm_pmi2
from hpccm.building_blocks.ucx import ucx
from hpccm.building_blocks.xpmem import xpmem
from hpccm.building_blocks.yum import yum
